//Check for browser support, initialise and attach eventslisteners
function registerEvents() {
    //Variables
    var audio = document.getElementById('audio');
    var btnStop = document.getElementById('stop');
    var messages = document.getElementById('messages');
    var controls = document.getElementById('controls');
    var slider = document.getElementById('slider');
    var volKnob = document.getElementById('volKnob');
    var audioTagSupport = !!(document.createElement('audio').canPlayType);
    //check for audio support
    if (audioTagSupport==false){
        messages.innerHTML="Sorry! your browser does not seem to support HTML5/mp3 audio";
    }
    else{
        stopPlayback();
        var tracks = document.getElementById('trackList').children;
        for (var i = 0; i < tracks.length; i++) {
            tracks[i].addEventListener('click', playTrack, false)
        }
        btnStop.addEventListener('click',stopPlayback,false);
        audio.addEventListener('ended', stopPlayback,false);
        slider.addEventListener('change', sliderFunc,false);
        volKnob.addEventListener('change', volFunc,false);
    }
}

//Functions called by the events
function playTrack (event) {
    event.preventDefault();
    messages.innerHTML='Loading...';
    try{
        if(audio.canPlayType("audio/mp3")){
            audio.setAttribute('src', this.href);
            audio.setAttribute('type', 'audio/mpeg');
        }
        else if(audio.canPlayType("audio/ogg")&& this.hasAttribute("data-oggfallback")){
            audio.setAttribute('src', this.getAttribute('data-oggfallback'));
            audio.setAttribute('type', 'audio/ogg');
        }
        else{
        messages.innerHTML='Your browser does not support playback of these files';
        }
    }
    catch(err){
        messages.innerHTML='Your browser does not seem to support HTML5 audio';
    }
    audio.load();
    audio.oncanplay = audio.play(), messages.innerHTML='Buffering...';
    audio.onplaying  = messages.innerHTML='Now playing: '+this.innerHTML;
    controls.style.display='block';
    audio.addEventListener('timeupdate', updateSlider, false);
}

function stopPlayback(){
    audio.pause();
    messages.innerHTML='Select a track';
    controls.style.display='none';
}
function sliderFunc (){
    var seekTo = audio.duration * (slider.value/100);
    audio.currentTime = seekTo;
}
function updateSlider () {
    var newTime = audio.currentTime * (100/audio.duration);
    slider.value = newTime;
}
function volFunc (){
    audio.volume = volKnob.value/10;
}

//Page Load
document.addEventListener('DOMContentLoaded', registerEvents, false);